summaryrefslogtreecommitdiffstats
path: root/src/structures
diff options
context:
space:
mode:
authorStepan Henek <stepan@henek.name>2020-03-27 15:36:37 +0100
committerStepan Henek <stepan@henek.name>2020-03-27 15:36:37 +0100
commit83a3286abe3ea845c0d3eb6551226a14791e21b3 (patch)
treec2e30855e596276269405c6d28a866d2a8fbbd71 /src/structures
parent79a38158f9d75fd98b93c0e629a8d40583f88cc1 (diff)
Add compile option to use skim binary instead of fzf binary
Diffstat (limited to 'src/structures')
-rw-r--r--src/structures/cheat.rs2
-rw-r--r--src/structures/finder.rs (renamed from src/structures/fzf.rs)8
-rw-r--r--src/structures/mod.rs2
-rw-r--r--src/structures/option.rs12
4 files changed, 12 insertions, 12 deletions
diff --git a/src/structures/cheat.rs b/src/structures/cheat.rs
index ef9230a..778a337 100644
--- a/src/structures/cheat.rs
+++ b/src/structures/cheat.rs
@@ -1,5 +1,5 @@
+use crate::structures::finder::Opts;
use crate::structures::fnv::HashLine;
-use crate::structures::fzf::Opts;
use std::collections::HashMap;
pub type Suggestion = (String, Option<Opts>);
diff --git a/src/structures/fzf.rs b/src/structures/finder.rs
index 5dd35a3..8e23035 100644
--- a/src/structures/fzf.rs
+++ b/src/structures/finder.rs
@@ -35,13 +35,13 @@ impl Default for Opts {
#[derive(Clone, Copy, Debug, PartialEq)]
pub enum SuggestionType {
- /// fzf will not print any suggestions
+ /// finder will not print any suggestions
Disabled,
- /// fzf will only select one of the suggestions
+ /// finder will only select one of the suggestions
SingleSelection,
- /// fzf will select multiple suggestions
+ /// finder will select multiple suggestions
MultipleSelections,
- /// fzf will select one of the suggestions or use the query
+ /// finder will select one of the suggestions or use the query
SingleRecommendation,
/// initial snippet selection
SnippetSelection,
diff --git a/src/structures/mod.rs b/src/structures/mod.rs
index b3cb886..8a23068 100644
--- a/src/structures/mod.rs
+++ b/src/structures/mod.rs
@@ -1,5 +1,5 @@
pub mod cheat;
pub mod error;
pub mod fnv;
-pub mod fzf;
+pub mod finder;
pub mod option;
diff --git a/src/structures/option.rs b/src/structures/option.rs
index a837351..53ec8e3 100644
--- a/src/structures/option.rs
+++ b/src/structures/option.rs
@@ -37,13 +37,13 @@ pub struct Config {
#[structopt(long)]
pub no_preview: bool,
- /// FZF overrides for cheat selection
- #[structopt(long, env = "NAVI_FZF_OVERRIDES")]
- pub fzf_overrides: Option<String>,
+ /// finder overrides for cheat selection
+ #[structopt(long, env = "NAVI_FINDER_OVERRIDES")]
+ pub finder_overrides: Option<String>,
- /// FZF overrides for variable selection
- #[structopt(long, env = "NAVI_FZF_OVERRIDES_VAR")]
- pub fzf_overrides_var: Option<String>,
+ /// finder overrides for variable selection
+ #[structopt(long, env = "NAVI_FINDER_OVERRIDES_VAR")]
+ pub finder_overrides_var: Option<String>,
#[structopt(subcommand)]
pub cmd: Option<Command>,